@@ -113,7 +113,7 @@ def choose_course(options):
         confirm(f"You are part of the course '{options[0]}'.")
         return options[0]
     else:
-        return click.choice(
+        return click.Choice(
             question("Choose your course:"), 
             type=click.Choice(options),
         )  
